@@ -98,7 +98,7 @@ around BUILD => sub ( $orig, $self, $args ) {
     for my $class ( keys $ext_map->{class}->%* ) {
         die qq["$class" must be lowercase alpha name] if $class !~ /\A[[:lower:]]+\z/sm;
 
-        die qq["ext_class_$class" method is required to generate ExtJS class] if !$self->can("ext_class_$class");
+        die qq["EXT_$class" method is required to generate ExtJS class] if !$self->can("EXT_$class");
 
         # find real base class name
         my $real_base_class_name = $Pcore::ExtJS::BOOTSTRAP->{classic}->{class}->{ $ext_map->{class}->{$class} };
@@ -165,7 +165,7 @@ around run => sub ( $orig, $self, $req ) {
               },
               'Pcore::ExtJS';
 
-            my $method = "ext_class_$internal_class_name";
+            my $method = "EXT_$internal_class_name";
 
             # call ExtJS class generation method
             $self->$method($ext);
