@@ -8,7 +8,7 @@ use WWW::CDN;
 
 with qw[Pcore::App::Controller::ExtJS];
 
-requires qw[ext_class_viewport];
+requires qw[EXT_viewport];
 
 has extjs_ver                   => ( is => 'ro', isa => Str, default => $WWW::CDN::LATEST_VERION->{extjs} );    # ExtJS framewrok version
 has extjs_default_theme_classic => ( is => 'ro', isa => Str, default => 'triton' );
